#define F_CPU 14745600

#define G4 1275 	//392 Herz
#define Ab4 1204 	//415 Herz
#define A4 1136 	//440 Herz
#define B4 1014 	//493 Herz

#define D5 851 		//587 Herz
#define Eb5 803 	//622 Herz
#define E5 758 		//659 Herz
#define F5 716 		//698 Herz
#define Fsh5 676 	//739 Herz
#define Gb5 676 	//739 Herz
#define G5 638 		//783 Herz
#define Gsh5 602 	//830 Herz
#define A5 568 		//880 Herz

#define C6 478 		//1046 Herz
#define D6 425 		//1174 Herz
#define E6 379 		//1318 Herz
#define F6 358 		//1396 Herz

#define DUR 18

#include <stdio.h>

#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <inttypes.h>

#include "../libnerdkits/lcd.h"
#include "../libnerdkits/uart.h"
#include "../libnerdkits/io_328p.h"

#include <inttypes.h>
#include <string.h>
#include "custom_characters.h"

#include <util/delay.h>
#include "../libnerdkits/delay.h"

#include "../mylibs/matrix_1_to_4_U.c"
#include "../mylibs/matrix_1_to_2_U.c"

// Global Variables
volatile uint8_t nx_btn, ch_btn, cur_room, st_sound, fn_sound, dir_btn = 0;
volatile uint8_t inv_sword, inv_key, inv_shoe, inv_shield, inv_princess = 0;

// Prototypes
void play_tone(uint16_t, uint8_t);
void lock_snd();
void secret_snd();
void theme_snd();
void dungeon_snd();

// Prototypes
void des_r00_p1(); void des_r00_p2(); void des_r00_p3(); void ch_r00_dir();
void des_r01_p1(); void des_r01_p2(); void des_r01_p3(); void ch_r01_dir();
void des_r02_p1(); void des_r02_p2(); void des_r02_p3(); void ch_r02_dir();
void des_r03_p1(); void des_r03_p2(); void des_r03_p3(); void ch_r03_dir(); void ch_r03_act();
void des_r04_p1(); void des_r04_p2(); void des_r04_p3(); void ch_r04_dir(); void ch_r04_act();
void des_r05_p1(); void des_r05_p2(); void des_r05_p3(); void ch_r05_dir();
void des_r06_p1(); void des_r06_p2(); void des_r06_p3(); void ch_r06_dir();
void des_r07_p1(); void des_r07_p2(); void des_r07_p3(); void ch_r07_dir(); void ch_r07_act();
void des_r08_p1(); void des_r08_p2(); void des_r08_p3(); void ch_r08_dir();
void des_r09_p1(); void des_r09_p2(); void des_r09_p3(); void ch_r09_dir();
void des_r10_p1(); void des_r10_p2(); void des_r10_p3(); void ch_r10_dir();
void des_r11_p1(); void des_r11_p2(); void des_r11_p3(); void ch_r11_dir();
void des_r12_p1(); void des_r12_p2(); void des_r12_p3(); void ch_r12_dir(); void ch_r12_act();
void des_r13_p1(); void des_r13_p2(); void des_r13_p3(); void ch_r13_dir(); void ch_r13_act();
void des_r14_p1(); void des_r14_p2(); void des_r14_p3(); void ch_r14_dir();
void des_r15_p1(); void des_r15_p2(); void des_r15_p3(); void ch_r15_dir(); void ch_r15_act();

void res_cnt_room_to_zero(); 
void res_cnt_room_to_one(); 
void res_cnt_room_to_two(); 
void res_cnt_room_to_three(); 
void res_cnt_room_to_four(); 
void res_cnt_room_to_five();
void res_cnt_room_to_six();
void res_cnt_room_to_seven();
void res_cnt_room_to_eight();
void res_cnt_room_to_nine();
void res_cnt_room_to_ten();
void res_cnt_room_to_eleven();
void res_cnt_room_to_twelve();
void res_cnt_room_to_thirteen();
void res_cnt_room_to_fourteen();
void res_cnt_room_to_fifteen();

void res_cnt_inv_sword();
void res_cnt_inv_key();
void res_cnt_inv_shoe();
void res_cnt_inv_shield();
void res_cnt_inv_princess();
void res_cnt_inv_dragon();

void res_cnt();
void no_act();
void ch_action();
void show_inventory();

void lock_symbol_chain();
void shield_symbol_chain();
void load_char_items();
void load_char_knight();
void load_char_princess();
void show_intro();
void clear_screen_mod();
void load_char_dragon();

  
int main(void) {

	// start up the LCD
	lcd_init();
	lcd_home();

	// internal RC oscillator calibration for 8MHz.
	OSCCAL = 176;
	
	DDRC |= (1<<PC3);  // Buzzer
	
	// LED as output
	DDRC |= (1<<PC1); // Green LED
	DDRC |= (1<<PC2); // Red LED
	
	// btn as Input
	DDRC &= ~(1<<PC4);
	
	// turn on the internal resistors for the pins
	PORTC |= (1<<PC4); // turn on internal pull up resistor

    init_matrix_1_to_4_keypad();
	init_matrix_1_to_2_keypad();
	
	cur_room = 0;
	
	load_char_items();
	//res_cnt_inv_princess();
	show_intro();
	  
  while(1)
  {
	// ##### btn 1 to 4 Matrix Section ######
		
	SETBIT(COL1_PORT,COL1_BIT);			//COL1 auf Masse ziehen
	CLEARBIT(COL1_PORT,COL1_BIT);		//COL1 auf Masse ziehen
		
	asm( "nop" );
        
	//prfen, ob ROW 1,2,3,4 einen Low-Pegel aufweisen
	if(!(CHECKBIT(ROW1_PIN,ROW1_BIT))) // When btn 3 pressed - Osten
	{
		if(nx_btn == 3 && ch_btn == 2) dir_btn=3;
		else if(nx_btn == 3 && ch_btn == 1) dir_btn=3;
		else{}
	}
	if(!(CHECKBIT(ROW2_PIN,ROW2_BIT))) // When btn 4 pressed - Westen
	{
		if(nx_btn == 3 && ch_btn == 2) dir_btn=4;
		else if(nx_btn == 3 && ch_btn == 1) dir_btn=4;
		else{}
	}
	if(!(CHECKBIT(ROW3_PIN,ROW3_BIT))) // When btn 1 pressed - Sden
	{			
		if(nx_btn == 3 && ch_btn == 2) dir_btn=2;
		else if(nx_btn == 3 && ch_btn == 1) dir_btn=2;  
		else{}
	}
	if(!(CHECKBIT(ROW4_PIN,ROW4_BIT))) // When btn 2 pressed - Norden
	{		
		if(nx_btn == 3 && ch_btn == 2)	dir_btn=1;
		else if(nx_btn == 3 && ch_btn == 1) dir_btn=1;
		else{}
	}
	
	// ##### btn 1 to 2 Matrix Section ######

	SETBIT(M1T2_COL1_PORT,M1T2_COL1_BIT);		//COL1 auf Masse ziehen
	CLEARBIT(M1T2_COL1_PORT,M1T2_COL1_BIT);		//COL1 auf Masse ziehen
		
	asm( "nop" );
        
	//prfen, ob ROW 1,2 einen Low-Pegel aufweisen
	if(!(CHECKBIT(M1T2_ROW1_PIN,M1T2_ROW1_BIT))) // When btn 1 pressed - Direction
	{
		if(nx_btn == 3){}
		else
		{
			nx_btn++;
			_delay_ms(450);			// Debouncing
		}	
	}
	if(!(CHECKBIT(M1T2_ROW2_PIN,M1T2_ROW2_BIT))) // When btn Start pressed - Next
	{		
		if(nx_btn < 3){} 
		else ch_btn=1;
	}
	
	// ##### btn n Section ######
	
	while(!(PINC & (1<<PC4))) 		// When btn 2 pressed - Action
	{
		if(nx_btn < 3){} 
		else ch_btn=2;
	}
	
	// ##### Room  Check Section #######

	// ## Room 00 ##
	if(cur_room == 0)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r00_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r00_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r00_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r00_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) res_cnt_room_to_four();	// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) res_cnt_room_to_two();	// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) res_cnt_room_to_one();	// Osten
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) res_cnt_room_to_three();	// Westen		
	}
	
	// ## Room 01 ##
	else if(cur_room == 1)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r01_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r01_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r01_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r01_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {} 							// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) {}							// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) res_cnt_room_to_fourteen();	// Osten
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) res_cnt_room_to_zero();  	// Westen
	}
	
	// ## Room 02 ##
	else if(cur_room == 2)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r02_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r02_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r02_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r02_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) res_cnt_room_to_zero();	// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) res_cnt_room_to_eight();	// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) {}						// Osten
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) {}						// Westen
	}
	
	// ## Room 03 ##
	else if(cur_room == 3)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r03_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r03_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r03_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) ch_r03_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) res_cnt_inv_key();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r03_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {}						// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) {}						// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) res_cnt_room_to_zero();	// Osten
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) {}						// Westen
	}
	
	// ## Room 04 ##
	else if(cur_room == 4)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r04_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r04_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r04_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) ch_r04_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) res_cnt_inv_sword();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r04_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) res_cnt_room_to_five();	// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) res_cnt_room_to_zero();	// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) {}						// Osten
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) {}						// Westen
	}
	
	// ## Room 05 ##
	else if(cur_room == 5)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r05_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r05_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r05_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r05_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {}						// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) res_cnt_room_to_four();	// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) res_cnt_room_to_six();	// Osten
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) {}						// Westen
	}
	
	// ## Room 06 ##
	else if(cur_room == 6)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r06_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r06_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r06_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r06_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {}						// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) {}						// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) res_cnt_room_to_seven();	// Osten	
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) res_cnt_room_to_five();	// Westen
	}

	// ## Room 07 ##
	else if(cur_room == 7)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r07_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r07_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r07_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) ch_r07_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) res_cnt_inv_shoe();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r07_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {}						// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) {}						// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) {}						// Osten
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) res_cnt_room_to_six();	// Westen
	}
	
	// ## Room 08 ##
	else if(cur_room == 8)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r08_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r08_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r08_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r08_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) res_cnt_room_to_two();	// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) {}						// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) res_cnt_room_to_nine();	// Osten
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) {}						// Westen
	}
	
	// ## Room 09 ##
	else if(cur_room == 9)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r09_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r09_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r09_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r09_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {}						// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) {}						// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) res_cnt_room_to_ten();	// Osten	
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) res_cnt_room_to_eight();	// Westen
	}
	
	// ## Room 10 ##
	else if(cur_room == 10)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r10_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r10_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r10_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r10_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {}						// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) {}						// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) res_cnt_room_to_eleven();// Osten	
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) res_cnt_room_to_nine();	// Westen
	}
	
	// ## Room 11 ##
	else if(cur_room == 11)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r11_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r11_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r11_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r11_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) res_cnt_room_to_twelve();// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) {}						// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) {}						// Osten	
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) res_cnt_room_to_ten();	// Westen
	}
	
	// ## Room 12 ##
	else if(cur_room == 12)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r12_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r12_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r12_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) ch_r12_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) res_cnt_inv_dragon();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r12_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {}						// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) res_cnt_room_to_eleven();// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) {}						// Osten	
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) {}						// Westen
	}
	
	// ## Room 13 ##
	else if(cur_room == 13)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r13_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r13_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r13_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) ch_r13_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) res_cnt_inv_princess();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r13_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {}						// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) res_cnt_room_to_twelve();// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) {}						// Osten	
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) {}						// Westen
	}
	
	// ## Room 14 ##
	else if(cur_room == 14)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r14_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r14_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r14_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) no_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r14_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) res_cnt_room_to_fifteen();// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) {}						// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) {}						// Osten	
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) res_cnt_room_to_one();	// Westen
	}
	
	// ## Room 15 ##
	else if(cur_room == 15)
	{
		if (nx_btn == 0 && ch_btn == 0 && dir_btn == 0) des_r15_p1();
		else if (nx_btn == 1 && ch_btn == 0 && dir_btn == 0) des_r15_p2();
		else if (nx_btn == 2 && ch_btn == 0 && dir_btn == 0) des_r15_p3();
		else if (nx_btn == 3 && ch_btn == 0 && dir_btn == 0) ch_action();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 0) ch_r15_act();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 1) res_cnt();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 2) res_cnt_inv_shield();
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 3) {}
		else if (nx_btn == 3 && ch_btn == 1 && dir_btn == 4) {}
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 0) ch_r15_dir();
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 1) {}							// Norden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 2) res_cnt_room_to_fourteen();	// Sden
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 3) {}							// Osten	
		else if (nx_btn == 3 && ch_btn == 2 && dir_btn == 4) {}							// Westen
	}
  }
	return 0;
}

   // ######  Function Section ########
  
  // ## Room 00
  void des_r00_p1()
{ 
  lcd_line_one();	lcd_write_string(PSTR("## Room 00 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("Es ist dunkel.      "));
  lcd_line_three();	lcd_write_string(PSTR("Alles ist verlassen "));
  lcd_line_four();	lcd_write_string(PSTR("du blickst,       >>"));
    
  show_inventory();
}

  void des_r00_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAA       >>"));
}

  void des_r00_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBB       >>"));
}

  void ch_r00_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("UP: Norden          "));
  lcd_line_two();	lcd_write_string(PSTR("DOWN: Sueden        "));
  lcd_line_three();	lcd_write_string(PSTR("RIGHT: Osten        "));
  lcd_line_four();	lcd_write_string(PSTR("LEFT: Westen        "));
}

// ## Room 01
  void des_r01_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 01 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAA       >>"));
  
  show_inventory();
}

  void des_r01_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBB       >>"));
}

  void des_r01_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCC       >>"));
}

  void ch_r01_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("RIGHT: Osten        "));
  lcd_line_four();	lcd_write_string(PSTR("LEFT: Westen        "));
}

// ## Room 02
  void des_r02_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 02 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r02_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r02_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r02_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("UP: Norden          "));
  lcd_line_two();	lcd_write_string(PSTR("DOWN: Sueden        "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

// ## Room 03
  void des_r03_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 03 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r03_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r03_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r03_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("RIGHT: Osten        "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}
  void ch_r03_act()
{
	if(inv_key == 0)
	{
	  lcd_line_one();	lcd_write_string(PSTR("UP: Keine Aktion.   "));
	  lcd_line_two();	lcd_write_string(PSTR("DOWN: Nimm Key.     "));
	  lcd_line_three();	lcd_write_string(PSTR("                    "));
	  lcd_line_four();	lcd_write_string(PSTR("                    "));
	}
	
	else if(inv_key == 1)
	{
	  lcd_line_one();	lcd_write_string(PSTR("UP: Keine Aktion.   "));
	  lcd_line_two();	lcd_write_string(PSTR("                    "));
	  lcd_line_three();	lcd_write_string(PSTR("                    "));
	  lcd_line_four();	lcd_write_string(PSTR("                    "));
	}
}

// ## Room 04
  void des_r04_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 04 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r04_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r04_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r04_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("UP: Norden          "));
  lcd_line_two();	lcd_write_string(PSTR("DOWN: Sueden        "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

  void ch_r04_act()
{
	if(inv_sword == 0)
	{
	  lcd_line_one();	lcd_write_string(PSTR("UP: Keine Aktion.   "));
	  lcd_line_two();	lcd_write_string(PSTR("DOWN: Nimm Schwert. "));
	  lcd_line_three();	lcd_write_string(PSTR("                    "));
	  lcd_line_four();	lcd_write_string(PSTR("                    "));
	}
	
	else if(inv_sword == 1)
	{
	  lcd_line_one();	lcd_write_string(PSTR("UP: Keine Aktion.   "));
	  lcd_line_two();	lcd_write_string(PSTR("                    "));
	  lcd_line_three();	lcd_write_string(PSTR("                    "));
	  lcd_line_four();	lcd_write_string(PSTR("                    "));
	}
}

// ## Room 05
  void des_r05_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 05 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r05_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r05_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r05_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("DOWN: Sueden        "));
  lcd_line_three();	lcd_write_string(PSTR("RIGHT: Osten        "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

// ## Room 06
  void des_r06_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 06 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r06_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r06_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r06_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("RIGHT: Osten        "));
  lcd_line_four();	lcd_write_string(PSTR("LEFT: Westen        "));
}

// ## Room 07
  void des_r07_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 07 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r07_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r07_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r07_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("LEFT: Westen        "));
}

  void ch_r07_act()
{
	if(inv_shoe == 0)
	{
	  lcd_line_one();	lcd_write_string(PSTR("UP: Keine Aktion.   "));
	  lcd_line_two();	lcd_write_string(PSTR("DOWN: Nimm Schuhe.  "));
	  lcd_line_three();	lcd_write_string(PSTR("                    "));
	  lcd_line_four();	lcd_write_string(PSTR("                    "));
	}
	
	else if(inv_shoe == 1)
	{
	  lcd_line_one();	lcd_write_string(PSTR("UP: Keine Aktion.   "));
	  lcd_line_two();	lcd_write_string(PSTR("                    "));
	  lcd_line_three();	lcd_write_string(PSTR("                    "));
	  lcd_line_four();	lcd_write_string(PSTR("                    "));
	}
}

// ## Room 08
  void des_r08_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 08 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r08_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r08_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r08_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("UP: Norden          "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("RIGHT: Osten        "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

// ## Room 09
  void des_r09_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 09 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r09_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r09_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r09_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("RIGHT: Osten        "));
  lcd_line_four();	lcd_write_string(PSTR("LEFT: Westen        "));
}

// ## Room 10
  void des_r10_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 10 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r10_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r10_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r10_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("RIGHT: Osten        "));
  lcd_line_four();	lcd_write_string(PSTR("LEFT: Westen        "));
}

// ## Room 11
  void des_r11_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 11 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r11_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r11_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r11_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("UP: Norden          "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("LEFT: Westen        "));
}

// ## Room 12
  void des_r12_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 12 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
    
  if (fn_sound==0)
	{
		dungeon_snd();
		fn_sound++;
	}
}

  void des_r12_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r12_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r12_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("DOWN: Sueden        "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

  void ch_r12_act()
{
  lcd_line_one();	lcd_write_string(PSTR("UP: Keine Aktion.   "));
  lcd_line_two();	lcd_write_string(PSTR("DOWN: Fight Drache. "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

// ## Room 13
  void des_r13_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 13 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r13_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r13_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r13_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("DOWN: Sueden        "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

  void ch_r13_act()
{
  lcd_line_one();	lcd_write_string(PSTR("UP: Keine Aktion.   "));
  lcd_line_two();	lcd_write_string(PSTR("DOWN: Rette Princess"));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

// ## Room 14
  void des_r14_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 14 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r14_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r14_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r14_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("UP: Norden          "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("LEFT: Westen        "));
}

// ## Room 15
  void des_r15_p1()
{
  lcd_line_one();	lcd_write_string(PSTR("## Room 15 ## I:"));
  lcd_line_two();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_three();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAAAAA"));
  lcd_line_four();	lcd_write_string(PSTR("AAAAAAAAAAAAAAAAA >>"));
  
  show_inventory();
}

  void des_r15_p2()
{
  lcd_line_one();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_two();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_three();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBBBBB"));
  lcd_line_four();	lcd_write_string(PSTR("BBBBBBBBBBBBBBBBB >>"));
}

  void des_r15_p3()
{
  lcd_line_one();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_two();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_three();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCCCCC"));
  lcd_line_four();	lcd_write_string(PSTR("CCCCCCCCCCCCCCCCC >>"));
}

  void ch_r15_dir()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("DOWN: Sueden        "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

  void ch_r15_act()
{
  if(inv_shield == 0)
  {
	lcd_line_one();	  lcd_write_string(PSTR("UP: Keine Aktion.   "));
	lcd_line_two();	  lcd_write_string(PSTR("DOWN: Nimm Schild.  "));
	lcd_line_three(); lcd_write_string(PSTR("                    "));
	lcd_line_four();  lcd_write_string(PSTR("                    "));
  }
  
  else if(inv_shield == 1)
  {
  	lcd_line_one();	  lcd_write_string(PSTR("UP: Keine Aktion.   "));
	lcd_line_two();	  lcd_write_string(PSTR("                    "));
	lcd_line_three(); lcd_write_string(PSTR("                    "));
	lcd_line_four();  lcd_write_string(PSTR("                    "));
  }
}

// ## Common
  void ch_action()
{
  lcd_line_one();	lcd_write_string(PSTR("Waehle deine Aktion:"));
  lcd_line_two();	lcd_write_string(PSTR("Btn 1: Fortbewegung."));
  lcd_line_three();	lcd_write_string(PSTR("Btn 2: Aktion.      "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

  void no_act()
{
  lcd_line_one();	lcd_write_string(PSTR("UP: Keine Aktion.   "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

void res_cnt()
{
	nx_btn = 0;
	ch_btn = 0;
	dir_btn = 0;
}

void res_cnt_inv_sword()
{
	if(inv_sword == 0)
	{
		res_cnt();
		inv_sword = 1;
		secret_snd();
	}
	
	else if(inv_sword == 1){}
}

void res_cnt_inv_key()
{
	if(inv_key == 0)
	{
		res_cnt();
		inv_key = 1;
		secret_snd();
	}
	
	else if(inv_key == 1) {}
}

void res_cnt_inv_shoe()
{
	if(inv_shoe== 0)
	{
		res_cnt();
		inv_shoe= 1;
		secret_snd();
	}
	
	else if(inv_shoe == 1) {}
}

void res_cnt_inv_shield()
{
	if(inv_shield== 0)
	{
		res_cnt();
		inv_shield= 1;
		secret_snd();
	}
	
	else if(inv_shield == 1) {}
}

void res_cnt_inv_dragon()
{
	res_cnt_room_to_thirteen();
}

void res_cnt_inv_princess()
{
	int i,j;
	
	lcd_clear_and_home();
	
	for (i=0; i<9; i++) {
		lcd_goto_position(3, i); lcd_loadCharSingle(0x05);
		lcd_goto_position(3, i-1); lcd_write_string(PSTR(" "));
		_delay_ms(500);
	}
		
	for (j=19; j>9; j--) {
		lcd_goto_position(3, j); lcd_loadCharSingle(0x05);
		lcd_goto_position(3, j+1); lcd_write_string(PSTR(" "));
		_delay_ms(500);
		}

	lcd_goto_position(2, 9); lcd_loadCharSingle(0x06);
	_delay_ms(1000);
	
	lcd_line_one();		lcd_write_string(PSTR("##    GAME OVER   ##"));
	lcd_goto_position(1, 4); shield_symbol_chain();
	_delay_ms(1000);
	
	theme_snd();
	
	while(1)
	{
		lcd_goto_position(3, 8); lcd_loadCharSingle(0x07);
		lcd_goto_position(3, 10); lcd_loadCharSingle(0x07);
			_delay_ms(500);
		lcd_goto_position(3, 8); lcd_loadCharSingle(0x05);
		lcd_goto_position(3, 10); lcd_loadCharSingle(0x05);
			_delay_ms(500);			
	}
}

void res_cnt_room_to_zero()
{
	res_cnt();
	cur_room = 0;	
}

void res_cnt_room_to_one()
{
	res_cnt();
	cur_room = 1;	
}

void res_cnt_room_to_two()
{
	res_cnt();
	cur_room = 2;	
}

void res_cnt_room_to_three()
{
	res_cnt();
	cur_room = 3;	
}

void res_cnt_room_to_four()
{
	res_cnt();
	cur_room = 4;	
}

void res_cnt_room_to_five()
{
	res_cnt();
	cur_room = 5;	
}

void res_cnt_room_to_six()
{
	if(inv_shield == 1)
	{
		res_cnt();
		cur_room = 6;	
	}
	
	else if (inv_shield == 0)
	{
		lcd_line_one();		lcd_write_string(PSTR("## Wait 5 seconds ##"));
		lcd_line_two();		lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));  
		lcd_line_three();	lcd_write_string(PSTR("xx   NO SHIELD ")); lcd_loadCharSingle(0x03); lcd_write_string(PSTR("  xx"));
		lcd_line_four();	lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));
		
		lock_snd();
	
		_delay_ms(5000);	
		
		res_cnt();
		cur_room = 5;	
	}
}

void res_cnt_room_to_seven()
{
	res_cnt();
	cur_room = 7;	
}

void res_cnt_room_to_eight()
{
	if(inv_key == 1)
	{
		res_cnt();
		cur_room = 8;	
	}
	
	else if (inv_key == 0)
	{
		lcd_line_one();		lcd_write_string(PSTR("## Wait 5 seconds ##"));
		lcd_line_two();		lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));  
		lcd_line_three();	lcd_write_string(PSTR("xx    NO KEY ")); lcd_loadCharSingle(0x01); lcd_write_string(PSTR("    xx"));
		lcd_line_four();	lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));
		
		lock_snd();
	
		_delay_ms(5000);	
		
		res_cnt();
		cur_room = 2;	
	}
}

void res_cnt_room_to_nine()
{
	res_cnt();
	cur_room = 9;	
}

void res_cnt_room_to_ten()
{
	if(inv_shoe == 1)
	{
		res_cnt();
		cur_room = 10;	
	}
	
	else if (inv_shoe == 0)
	{
		lcd_line_one();		lcd_write_string(PSTR("## Wait 5 seconds ##"));
		lcd_line_two();		lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));  
		lcd_line_three();	lcd_write_string(PSTR("xx   NO SHOES ")); lcd_loadCharSingle(0x00); lcd_write_string(PSTR("   xx"));
		lcd_line_four();	lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));
		
		lock_snd();
	
		_delay_ms(5000);	
		
		res_cnt();
		cur_room = 9;	
	}
}

void res_cnt_room_to_eleven()
{
	res_cnt();
	cur_room = 11;	
}

void res_cnt_room_to_twelve()
{
	if(inv_sword == 1)
	{
		res_cnt();
		cur_room = 12;	
	}
	
	else if (inv_sword == 0)
	{
		lcd_line_one();		lcd_write_string(PSTR("## Wait 5 seconds ##"));
		lcd_line_two();		lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));
		lcd_line_three();	lcd_write_string(PSTR("xx   NO SWORD ")); lcd_loadCharSingle(0x04); lcd_write_string(PSTR("   xx"));
		lcd_line_four();	lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));
		
		lock_snd();
	
		_delay_ms(5000);	
		
		res_cnt();
		cur_room = 11;	
	}
}

void res_cnt_room_to_thirteen()
{
	res_cnt();
	cur_room = 13;	
}

void res_cnt_room_to_fourteen()
{
	if(inv_key == 1)
	{
		res_cnt();
		cur_room = 14;	
	}
	
	else if (inv_key == 0)
	{
		lcd_line_one();		lcd_write_string(PSTR("## Wait 5 seconds ##"));
		lcd_line_two();		lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));  
		lcd_line_three();	lcd_write_string(PSTR("xx    NO KEY ")); lcd_loadCharSingle(0x01); lcd_write_string(PSTR("    xx"));
		lcd_line_four();	lcd_write_string(PSTR("xx   ")); lock_symbol_chain(); lcd_write_string(PSTR("   xx"));
		
		lock_snd();
	
		_delay_ms(5000);	
		
		res_cnt();
		cur_room = 1;	
	}
}

void res_cnt_room_to_fifteen()
{
	res_cnt();
	cur_room = 15;	
}

void lock_symbol_chain()
{    
	int i = 0;

	for (i=0; i<10; i++) {
		lcd_loadCharSingle(0x02);
	}
}

void shield_symbol_chain()
{    
	int i = 0;

	for (i=0; i<13; i++) {
		lcd_loadCharSingle(0x03);
	}
}

void show_inventory()
{
  if(inv_sword == 1) lcd_loadChar(0,16,0x04);
  	else
	{
		lcd_goto_position(0, 16);
		lcd_write_string(PSTR(" "));
	}
  if(inv_key == 1) lcd_loadChar(0,17,0x01);
	else
	{
		lcd_goto_position(0, 17);
		lcd_write_string(PSTR(" "));
	}
  if(inv_shoe == 1) lcd_loadChar(0,18,0x00);
  	else
	{
		lcd_goto_position(0, 18);
		lcd_write_string(PSTR(" "));
	}
  if(inv_shield == 1) lcd_loadChar(0,19,0x03);
  	else
	{
		lcd_goto_position(0, 19);
		lcd_write_string(PSTR(" "));
	}
}

void load_char_items()
{
  lcd_createChar(0, pattern00);		// Create Char on position 0x00
  lcd_createChar(1, pattern01);		// Create Char on position 0x01
  lcd_createChar(2, pattern02);		// Create Char on position 0x02
  lcd_createChar(3, pattern03);		// Create Char on position 0x03
  lcd_createChar(4, pattern04);		// Create Char on position 0x04
  lcd_createChar(5, pattern05);		// Create Char on position 0x05
  lcd_createChar(6, pattern06);		// Create Char on position 0x06
  lcd_createChar(7, pattern07);		// Create Char on position 0x07
}

void load_char_knight()
{
  lcd_createChar(0, p_knight_L1F1);		// Create Char on position 0x00
  lcd_createChar(1, p_knight_L1F2);		// Create Char on position 0x01
  lcd_createChar(2, p_knight_L1F3);		// Create Char on position 0x02
  lcd_createChar(3, p_knight_L2F1);		// Create Char on position 0x03
  lcd_createChar(4, p_knight_L2F2);		// Create Char on position 0x04
  lcd_createChar(5, p_knight_L2F3);		// Create Char on position 0x05
}

void load_char_princess()
{
  lcd_createChar(0, p_princess_L1F1);		// Create Char on position 0x00
  lcd_createChar(1, p_princess_L1F2);		// Create Char on position 0x01
  lcd_createChar(2, p_princess_L1F3);		// Create Char on position 0x02
  lcd_createChar(3, p_princess_L2F1);		// Create Char on position 0x03
  lcd_createChar(4, p_princess_L2F2);		// Create Char on position 0x04
  lcd_createChar(5, p_princess_L2F3);		// Create Char on position 0x05
}

void load_char_dragon()
{
  lcd_createChar(0, p_dragon_L1F1);		// Create Char on position 0x00
  lcd_createChar(1, p_dragon_L1F2);		// Create Char on position 0x01
  lcd_createChar(2, p_dragon_L1F3);		// Create Char on position 0x02
  lcd_createChar(3, p_dragon_L2F1);		// Create Char on position 0x03
  lcd_createChar(4, p_dragon_L2F2);		// Create Char on position 0x04
  lcd_createChar(5, p_dragon_L2F3);		// Create Char on position 0x05
}

void show_intro()
{
		lcd_goto_position(0, 3); shield_symbol_chain();
		lcd_goto_position(1, 3); lcd_write_string(PSTR("   DRAGON    "));
		lcd_goto_position(2, 3); lcd_write_string(PSTR("   QUEST I   "));
		lcd_goto_position(3, 3); shield_symbol_chain();
		
	if (st_sound==0)
	{
		theme_snd();
		st_sound++;
	}
	
	clear_screen_mod();
	load_char_knight();

	lcd_loadChar(1,1,0x00);
	lcd_loadChar(1,2,0x01);
	lcd_loadChar(1,3,0x02);
	lcd_loadChar(2,1,0x03);
	lcd_loadChar(2,2,0x04);
	lcd_loadChar(2,3,0x05);
	
		lcd_goto_position(0, 5); lcd_write_string(PSTR("Unterstuetze  "));
		lcd_goto_position(1, 5); lcd_write_string(PSTR("den tapferen  "));
		lcd_goto_position(2, 5); lcd_write_string(PSTR("Ritter bei der"));
		lcd_goto_position(3, 5); lcd_write_string(PSTR("Befreiung der "));
	
	_delay_ms(5000);
	
	clear_screen_mod();
	load_char_princess();
	
	lcd_loadChar(1,1,0x00);
	lcd_loadChar(1,2,0x01);
	lcd_loadChar(1,3,0x02);
	lcd_loadChar(2,1,0x03);
	lcd_loadChar(2,2,0x04);
	lcd_loadChar(2,3,0x05);
	
		lcd_goto_position(0, 5); lcd_write_string(PSTR("entfuehrten  "));
		lcd_goto_position(1, 5); lcd_write_string(PSTR("Prinzessin   "));
		lcd_goto_position(2, 5); lcd_write_string(PSTR("aus den      "));
		lcd_goto_position(3, 5); lcd_write_string(PSTR("Faengen des  "));
	
	_delay_ms(5000);
	
	clear_screen_mod();
	load_char_dragon();
	
	lcd_loadChar(1,1,0x00);
	lcd_loadChar(1,2,0x01);
	lcd_loadChar(1,3,0x02);
	lcd_loadChar(2,1,0x03);
	lcd_loadChar(2,2,0x04);
	lcd_loadChar(2,3,0x05);
	
		lcd_goto_position(0, 5); lcd_write_string(PSTR("gefaehrlichen"));
		lcd_goto_position(1, 5); lcd_write_string(PSTR("riesigen     "));
		lcd_goto_position(2, 5); lcd_write_string(PSTR("schrecklichen"));
		lcd_goto_position(3, 5); lcd_write_string(PSTR("Drachen.     "));
	
	_delay_ms(5000);
	
	clear_screen_mod();
	
		lcd_goto_position(0, 3); lcd_write_string(PSTR("Deine Reise   "));
		lcd_goto_position(1, 3); lcd_write_string(PSTR("zur Rettung   "));
		lcd_goto_position(2, 3); lcd_write_string(PSTR("beginnt jetzt."));
		lcd_goto_position(3, 3); lcd_write_string(PSTR("Viel Glueck!  "));
		
	_delay_ms(5000);
	
	load_char_items();
}

void clear_screen_mod()
{
  lcd_line_one();	lcd_write_string(PSTR("                    "));
  lcd_line_two();	lcd_write_string(PSTR("                    "));
  lcd_line_three();	lcd_write_string(PSTR("                    "));
  lcd_line_four();	lcd_write_string(PSTR("                    "));
}

void play_tone(uint16_t delay, uint8_t duration) {

  uint16_t tmp = 100 * duration;
  uint16_t delaysm = delay / 50;
  uint16_t cycles = tmp / delaysm;
  
  while(cycles > 0) {
    PORTC |= (1<<PC3);
    delay_us(delay);
    PORTC &= ~(1<<PC3);
    delay_us(delay);
    cycles--;
  }
}

void lock_snd()
{
	play_tone(Gsh5/2, DUR/2);
	play_tone(Fsh5/2, 2*DUR);
}

void secret_snd()
{
	_delay_ms(500);
	play_tone(G5/2, DUR/2);
	play_tone(Gb5/2, DUR/2);
	play_tone(Eb5/2, DUR/2);
	play_tone(A4/2, DUR/2);
	play_tone(Ab4/2, DUR/2);
	play_tone(E5/2, DUR/2);
	play_tone(Gsh5/2, DUR/2);
	play_tone(C6/2, DUR/2);
}

void theme_snd()
{
  _delay_ms(500);
  play_tone(D5, DUR*0.5);
  play_tone(F5, DUR*0.5);
  play_tone(D6, DUR*1.5);

  play_tone(D5, DUR*0.5);
  play_tone(F5, DUR*0.5);
  play_tone(D6, DUR*1.5);
  
  play_tone(E6, DUR*1.125);
  play_tone(F6, DUR*0.45);
  play_tone(E6, DUR*0.45);
  play_tone(F6, DUR*0.45);
 
  play_tone(E6, DUR*0.5);
  play_tone(C6, DUR*0.45);
  play_tone(A5, DUR*1.5);
}

void dungeon_snd()
{
	play_tone(G4/2, DUR/2.5);
    play_tone(B4/2, DUR/2.5);                   
    play_tone(D5/2, DUR/2.5);
    play_tone(E5/2, DUR/2.5);
	
	play_tone(G4/2, DUR/2.5);
    play_tone(B4/2, DUR/2.5);                   
    play_tone(D5/2, DUR/2.5);
    play_tone(E5/2, DUR/2.5);
	
	play_tone(G4/2, DUR/2.5);
    play_tone(B4/2, DUR/2.5);                   
    play_tone(D5/2, DUR/2.5);
    play_tone(E5/2, DUR/2.5);
	
	play_tone(G4/2, DUR/2.5);
    play_tone(B4/2, DUR/2.5);                   
    play_tone(D5/2, DUR/2.5);
    play_tone(E5/2, DUR/2.5);
}